@@ -193,12 +193,12 @@ class psutilTemperaturePackage():
                 label = FALLBACK_SENSOR_LABEL.format(index)
             if sensor.hasCurrent():
                 attributes[label +
-                           " - Current"] = str(sensor.getCurrent()) + "°C"
+                           " - Current"] = sensor.getCurrent()
             if sensor.hasHighest():
                 attributes[label +
-                           " - Highest"] = str(sensor.getHighest()) + "°C"
+                           " - Highest"] = sensor.getHighest()
             if sensor.hasCritical():
-                attributes[label + " - Critical"] = str(sensor.getCritical()) + "°C"
+                attributes[label + " - Critical"] = sensor.getCritical()
         return attributes
 
 
