@@ -1,6 +1,7 @@
 from IoTuring.Logger.Logger import Logger
 from IoTuring.Warehouse.Warehouse import Warehouse
-
+from IoTuring.Entity.ValueFormat import ValueFormatter
+from IoTuring.Entity.EntityData import EntitySensor
 
 class ConsoleWarehouse(Warehouse):
     NAME = "Console"
@@ -10,4 +11,7 @@ class ConsoleWarehouse(Warehouse):
             for entitySensor in entity.GetEntitySensors():
                 if(entitySensor.HasValue()):
                     self.Log(Logger.LOG_MESSAGE, entitySensor.GetId() +
-                             ": " + entitySensor.GetValue())
+                             ": " + self.FormatValue(entitySensor))
+
+    def FormatValue(self, entitySensor: EntitySensor):
+        return ValueFormatter.FormatValue(entitySensor.GetValue(), entitySensor.GetValueFormatterOptions(), True)
\ No newline at end of file
